# remirepo spec file for php-pecl-xlswriter
#
# Copyright (c) 2018-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%if 0%{?scl:1}
%scl_package         php-pecl-xlswriter
%global sub_prefix   %{scl_prefix}
%endif

%global with_tests   0%{!?_without_tests:1}
%global with_zts     0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name    xlswriter
# After json
%global ini_name     40-%{pecl_name}.ini

# No soname, so manage dependency on available version
%global libxlsxwriter_version 1.0.0
%global libxlsxio_version     0.2.29

Summary:        An efficient and fast xlsx file export extension
Name:           %{?sub_prefix}php-pecl-%{pecl_name}
Version:        1.3.6
Release:        7%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        BSD
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

# from https://github.com/viest/php-ext-xlswriter/pull/298
Patch0:         xlswriter-php8.patch

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  libxlsxwriter-devel >= %{libxlsxwriter_version}
BuildRequires:  libxlsxio-devel >= %{libxlsxio_version}
BuildRequires:  zlib-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}
Requires:       libxlsxwriter%{?_isa} >= %{libxlsxwriter_version}
Requires:       libxlsxio%{?_isa} >= %{libxlsxio_version}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.1"
Obsoletes:     php71u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php71w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name} <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name} <= %{version}
Obsoletes:     php74w-pecl-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
An efficient and fast xlsx file export extension for PHP.

- Quickly export xlsx files in php projects.
- Export xlsx files under fixed memory.
- Insert a calculation formula in an xlsx file.
- Insert a local picture in an xlsx file.
- Merging cells and cell styles.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{pecl_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -e '/name="library/d' \
    -i package.xml

cd NTS
%patch0 -p1 -b .pr

# we use the system libraries
rm -r library

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_XLSWRITER_VERSION/{s/.* "//;s/".*$//;p}' php_xlswriter.h)
if test "x${extver}" != "x%{version}%{?prever:-%{prever}}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever:-%{prever}}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{pecl_name}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

peclbuild() {
%configure \
    --with-xlswriter \
    --with-libxlsxwriter=%{_prefix} \
    --with-libxlsxio=%{_prefix} \
    --enable-reader \
    --with-php-config=$1

make %{?_smp_mflags}
}

cd NTS
%{_bindir}/phpize
peclbuild %{_bindir}/php-config

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
peclbuild %{_bindir}/zts-php-config
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
# https://github.com/brechtsanders/xlsxio/issues/75
rm ?TS/tests/open_xlsx_get_data_skip_empty.phpt
rm ?TS/tests/open_xlsx_next_row_skip_empty.phpt

modules="-d extension=json.so"

cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    $modules \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep ^%{pecl_name}

%if %{with_tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    $modules \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep ^%{pecl_name}

%if %{with_tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/zts-php \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{_bindir}/zts-php -n run-tests.php --show-diff
%endif
%endif
cd ..


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Sep  8 2020 Remi Collet <remi@remirepo.net> - 1.3.6-7
- build using libxlsxwriter version 1.0.0

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.3.6-6
- add patch for PHP 8.0.0beta3 from
  https://github.com/viest/php-ext-xlswriter/pull/298

* Tue Aug 18 2020 Remi Collet <remi@remirepo.net> - 1.3.6-5
- build using libxlsxwriter version 0.9.9

* Tue Aug 11 2020 Remi Collet <remi@remirepo.net> - 1.3.6-4
- build using libxlsxwriter version 0.9.8

* Fri Aug  7 2020 Remi Collet <remi@remirepo.net> - 1.3.6-3
- build using libxlsxwriter version 0.9.7

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 1.3.6-2
- rebuild for 8.0.0beta1

* Wed Jun 17 2020 Remi Collet <remi@remirepo.net> - 1.3.6-1
- update to 1.3.6

* Mon Jun  1 2020 Remi Collet <remi@remirepo.net> - 1.3.5-2
- build using libxlsxwriter version 0.9.5

* Tue May 26 2020 Remi Collet <remi@remirepo.net> - 1.3.5-1
- update to 1.3.5
- drop patch merged upstream

* Mon Apr 13 2020 Remi Collet <remi@remirepo.net> - 1.3.4.1-1
- update to 1.3.4.1

* Tue Mar 24 2020 Remi Collet <remi@remirepo.net> - 1.3.4-2
- rebuild using libxlsxio version 0.2.26

* Thu Mar 19 2020 Remi Collet <remi@remirepo.net> - 1.3.4-1
- update to 1.3.4
- build using libxlsxwriter version 0.9.4
- build using libxlsxio version 0.2.24-2

* Tue Jan 14 2020 Remi Collet <remi@remirepo.net> - 1.3.3.2-2
- rebuild with libxlsxwriter 0.9.3
- add patch from https://github.com/viest/php-ext-xlswriter/pull/226

* Wed Jan  1 2020 Remi Collet <remi@remirepo.net> - 1.3.3.2-1
- update to 1.3.3.2

* Tue Dec 31 2019 Remi Collet <remi@remirepo.net> - 1.3.3.1-2
- rebuild with libxlsxwriter 0.9.1

* Fri Dec 27 2019 Remi Collet <remi@remirepo.net> - 1.3.3.1-1
- update to 1.3.3.1

* Thu Dec 26 2019 Remi Collet <remi@remirepo.net> - 1.3.3-2
- update to 1.3.3

* Wed Dec 18 2019 Remi Collet <remi@remirepo.net> - 1.3.2-2
- rebuild with libxlsxwriter 0.8.9

* Thu Nov 21 2019 Remi Collet <remi@remirepo.net> - 1.3.2-1
- update to 1.3.2
- drop patch merged upstream

* Mon Nov 18 2019 Remi Collet <remi@remirepo.net> - 1.3.1-2
- rebuild with libxlsxwriter 0.8.8
- open https://github.com/viest/php-ext-excel-export/pull/199
  fix compatibility with 0.8.8

* Sat Oct 12 2019 Remi Collet <remi@remirepo.net> - 1.3.1-1
- update to 1.3.1

* Wed Sep 25 2019 Remi Collet <remi@remirepo.net> - 1.3.0-1
- update to 1.3.0

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.2.9-2
- update to 1.2.9 (new tag)
- drop patches merged upstream

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.2.9-1
- update to 1.2.9
- drop patch merged upstream
- add fix for 32-bit build from
  https://github.com/viest/php-ext-excel-export/pull/173
  https://github.com/viest/php-ext-excel-export/pull/174

* Mon Sep 16 2019 Remi Collet <remi@remirepo.net> - 1.2.8-4
- build with system libxlsxio using patch from
  https://github.com/viest/php-ext-excel-export/pull/165

* Sat Sep 14 2019 Remi Collet <remi@remirepo.net> - 1.2.8-3
- update to 1.2.8 (new tarball)
- drop missing source added upstream

* Sat Sep 14 2019 Remi Collet <remi@remirepo.net> - 1.2.8-2
- update to 1.2.8 (new tarball)
- drop patch merged upstream
- open https://github.com/viest/php-ext-excel-export/pull/163
  missing file

* Sat Sep 14 2019 Remi Collet <remi@remirepo.net> - 1.2.8-1
- update to 1.2.8

* Fri Sep  6 2019 Remi Collet <remi@remirepo.net> - 1.2.7-2
- enable the reader
- add patch to fix config.m4 from
  https://github.com/viest/php-ext-excel-export/pull/158

* Fri Sep  6 2019 Remi Collet <remi@remirepo.net> - 1.2.7-1
- update to 1.2.7

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.2.6-3
- rebuild for 7.4.0RC1

* Wed Jul 10 2019 Remi Collet <remi@remirepo.net> - 1.2.6-2
- new upstream sources
- drop patch merged upstream

* Wed Jul 10 2019 Remi Collet <remi@remirepo.net> - 1.2.6-1
- update to 1.2.6

* Mon Jul  1 2019 Remi Collet <remi@remirepo.net> - 1.2.5-1
- update to 1.2.5

* Fri Jun 21 2019 Remi Collet <remi@remirepo.net> - 1.2.4-2
- rebuild with libxlsxwriter 0.8.7
- open https://github.com/viest/php-ext-excel-export/pull/132
  fix compatibility with 0.8.7

* Sat May  4 2019 Remi Collet <remi@remirepo.net> - 1.2.4-1
- update to 1.2.4

* Sun Nov 25 2018 Remi Collet <remi@remirepo.net> - 1.2.3-1
- update to 1.2.3

* Tue Oct  2 2018 Remi Collet <remi@remirepo.net> - 1.2.2-8
- rebuild with libxlsxwriter 0.8.3

* Mon Sep 17 2018 Remi Collet <remi@remirepo.net> - 1.2.2-7
- rebuild with libxlsxwriter 0.8.2

* Sun Sep 16 2018 Remi Collet <remi@remirepo.net> - 1.2.2-6
- rebuild with libxlsxwriter 0.8.1

* Wed Sep 12 2018 Remi Collet <remi@remirepo.net> - 1.2.2-5
- rebuild with libxlsxwriter 0.8.0
- open https://github.com/viest/php-ext-excel-export/pull/84

* Fri Aug 31 2018 Remi Collet <remi@remirepo.net> - 1.2.2-4
- rebuild with libxlsxwriter 0.7.8
- open https://github.com/viest/php-ext-excel-export/pull/81

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.2.2-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.2.2-2
- rebuild for 7.3.0alpha4 new ABI

* Thu Jul 12 2018 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2

* Sun Jun  3 2018 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1
- drop patch merged upstream

* Fri Jun  1 2018 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0
- add patch to fix reflection from
  https://github.com/viest/php-ext-excel-export/pull/71

* Thu May 31 2018 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Sun May 27 2018 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2 (no change)

* Fri May 25 2018 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1 (no change)
- all PRs merged upstream

* Fri May 25 2018 Remi Collet <remi@remirepo.net> - 1.0.0-1
- initial package, version 1.0.0 (stable)
- open https://github.com/viest/php-ext-excel-export/pull/55 macro name
- open https://github.com/viest/php-ext-excel-export/pull/56 CLEAN section
- open https://github.com/viest/php-ext-excel-export/pull/57 stable
